from django.test import TestCase
from ants.utils import *
from ants.decorators import *


class ScriptTest(TestCase):

    def setUp(self):
        pass


class DecoratorTest(TestCase):

    def setUp(self):
        pass
